function menu = flatten_menu(menu)
% Converts a menu with submenus into a flat menu
%
%   menu = flatten_menu(menu)
%
%   Input Arguments:
%       menu - the menu to flatten
%   Output Arguments:
%       menu - return a flattened menu
%
    menu.flat = true;
    
    % find the submenus
    submenu_pos = cellfun(@(x)(isequal(x.action,@sub_menu)),menu.entries);   
    submenus = menu.entries(submenu_pos);
    
    % the number of entries in the other column
    other = 1 + length(menu.options) + sum(submenu_pos == 0); 
    max_entries = other;
    for i=1:length(submenus)
        submenus{i} = submenus{i}.args{1};
        max_entries = max(max_entries,length(submenus{i}.entries));
    end
    
    %allocate the lines
    menu.lines = cell(1,max_entries + 1);
    
    % create the menu display
    letter = 'a';
    for i = 1:length(submenus)
        menu.lines{1} = [menu.lines{1},submenus{i}.title,'             '];
        for j=1:length(submenus{i}.entries)
            menu.translator.(letter) = 
            if letter(end) == 'z'
                letter = [letter,'a'];
            else
                letter(end) = letter(end) + 1;
            end
        end
    end
    
    menu.lines{1} = [menu.lines{1},'Other'];

    
end